package com.ruoyi.system.utils;

import com.ruoyi.common.core.utils.JwtUtils;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.URL;
import java.nio.file.Files;
import java.nio.file.LinkOption;
import java.nio.file.OpenOption;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.Comparator;
import java.util.HashMap;
import java.util.Map;
import java.util.zip.ZipEntry;
import java.util.zip.ZipInputStream;
import java.util.zip.ZipOutputStream;

public class ZipTool {
   public static void main(String[] args) {
      String urlString = "https://file.movfen.com/sync-cloud/base/woo-synchronous-payment.zip";
      Path newZipPath = generateWpPlugin(urlString, "https://wanxitrading.com", "https://wanxitrading.com", "woo-synchronous-payment-release");
      System.out.println("New zip file created at: " + newZipPath.toAbsolutePath());
   }

   public static Path generateWpPlugin(String urlString, String pluginDomain, String backDomain, String pluginName) {
      try {
         Map<String, Object> claims = new HashMap();
         claims.put("domain", pluginDomain);
         claims.put("time", System.currentTimeMillis());
         String key = JwtUtils.createToken(claims);
         String content = "<?php\n\nreturn [\n    'url' => '" + backDomain + "',\n    'key' => '" + key + "'\n];";
         return createAndProcessZip(urlString, "profile.php", content, pluginName);
      } catch (IOException var7) {
         IOException e = var7;
         e.printStackTrace();
         return null;
      }
   }

   public static Path createAndProcessZip(String fileUrl, String profileFileName, String profileContent, String pluginName) throws IOException {
      String timestamp = System.currentTimeMillis() + "";
      Path projectRoot = Paths.get("").toAbsolutePath();
      Path tempDir = Files.createDirectories(projectRoot.resolve("tempDir_" + System.currentTimeMillis()));
      Path zipPath = tempDir.resolve("downloaded.zip");
      downloadFile(fileUrl, zipPath);
      Path unzipDir = tempDir.resolve("unzipped");
      unzip(zipPath, unzipDir);
      Path profilePath = unzipDir.resolve(pluginName + "/" + profileFileName);
      Files.write(profilePath, profileContent.getBytes(), new OpenOption[0]);
      Path newZipPath = projectRoot.resolve("new-package_" + timestamp + ".zip");
      zipDirectory(unzipDir, newZipPath);
      deleteDirectory(tempDir);
      return newZipPath;
   }

   private static void downloadFile(String fileUrl, Path destination) throws IOException {
      InputStream in = (new URL(fileUrl)).openStream();

      try {
         OutputStream out = Files.newOutputStream(destination);

         try {
            byte[] buffer = new byte[1024];

            int bytesRead;
            while((bytesRead = in.read(buffer)) != -1) {
               out.write(buffer, 0, bytesRead);
            }
         } catch (Throwable var8) {
            if (out != null) {
               try {
                  out.close();
               } catch (Throwable var7) {
                  var8.addSuppressed(var7);
               }
            }

            throw var8;
         }

         if (out != null) {
            out.close();
         }
      } catch (Throwable var9) {
         if (in != null) {
            try {
               in.close();
            } catch (Throwable var6) {
               var9.addSuppressed(var6);
            }
         }

         throw var9;
      }

      if (in != null) {
         in.close();
      }

   }

   private static void unzip(Path zipFile, Path outputDir) throws IOException {
      ZipInputStream zis = new ZipInputStream(Files.newInputStream(zipFile));

      ZipEntry entry;
      try {
         for(; (entry = zis.getNextEntry()) != null; zis.closeEntry()) {
            Path entryPath = outputDir.resolve(entry.getName());
            if (entry.isDirectory()) {
               Files.createDirectories(entryPath);
            } else {
               Files.createDirectories(entryPath.getParent());
               OutputStream fos = Files.newOutputStream(entryPath);

               try {
                  byte[] buffer = new byte[1024];

                  int bytesRead;
                  while((bytesRead = zis.read(buffer)) != -1) {
                     fos.write(buffer, 0, bytesRead);
                  }
               } catch (Throwable var10) {
                  if (fos != null) {
                     try {
                        fos.close();
                     } catch (Throwable var9) {
                        var10.addSuppressed(var9);
                     }
                  }

                  throw var10;
               }

               if (fos != null) {
                  fos.close();
               }
            }
         }
      } catch (Throwable var11) {
         try {
            zis.close();
         } catch (Throwable var8) {
            var11.addSuppressed(var8);
         }

         throw var11;
      }

      zis.close();
   }

   private static void zipDirectory(Path sourceDir, Path zipFile) throws IOException {
      ZipOutputStream zos = new ZipOutputStream(Files.newOutputStream(zipFile));

      try {
         Files.walk(sourceDir).filter((x$0) -> {
            return Files.isRegularFile(x$0, new LinkOption[0]);
         }).forEach((path) -> {
            try {
               ZipEntry zipEntry = new ZipEntry(sourceDir.relativize(path).toString());
               zos.putNextEntry(zipEntry);
               Files.copy(path, zos);
               zos.closeEntry();
            } catch (IOException var4) {
               IOException e = var4;
               e.printStackTrace();
            }

         });
      } catch (Throwable var6) {
         try {
            zos.close();
         } catch (Throwable var5) {
            var6.addSuppressed(var5);
         }

         throw var6;
      }

      zos.close();
   }

   public static void deleteDirectory(Path path) throws IOException {
      Files.walk(path).sorted(Comparator.reverseOrder()).forEach((p) -> {
         try {
            Files.delete(p);
         } catch (IOException var2) {
            IOException e = var2;
            e.printStackTrace();
         }

      });
   }
}
